@@ -6,8 +6,8 @@ from types import ModuleType
 
 # __all__ is computed below.
 __pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtAxContainer", "QtWebChannel", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.9.0"
-__version_info__ = (6, 9, 0, "", "")
+__version__ = "6.9.1"
+__version_info__ = (6, 9, 1, "", "")
 
 SKIP_MYPY_TEST = bool("")
 
@@ -101,10 +101,13 @@ def _find_all_qt_modules():
 
     # Instead, we use __getattr__ which is supported since Python 3.7
     # and create the __all__ list on demand when needed.
-    location = Path(__file__).resolve().parent
-    files = os.listdir(location)
-    unordered = set(name[: name.find(".")] for name in files if name.startswith("Qt") and (
-                                                                name.endswith((".pyd", ".so"))))
+    unordered = set()
+    pattern = "Qt*.pyd" if sys.platform == "win32" else "Qt*.so"
+    for module in Path(__file__).resolve().parent.glob(pattern):
+        name = module.name[:module.name.find(".")]
+        if name.endswith("_d"):  # Windows debug suffix?
+            name = name[:-2]
+        unordered.add(name)
     ordered_part = __pre_all__
     result = []
     for name in ordered_part:
